from django.conf.urls import patterns, include, url
from hazinses.views import SNSMessageView

sns_message = SNSMessageView

urlpatterns = patterns(
    '',
    url(r'^sns/$',
        sns_message.as_view(),
        name="sns_message")
)



import boto.ses
import celery
import datetime
from django.conf import settings
from django.contrib.auth.models import User
from django.http import HttpResponse
from hazinses.models import UserEmailProfile, SentMail


conn = boto.ses.connect_to_region(
    settings.AMAZON_REGION,
    aws_access_key_id=settings.AWS_ACCESS_KEY_ID,
    aws_secret_access_key=settings.AWS_SECRET_ACCESS_KEY)


@celery.task
def send_email(subject, message, from_email, to_email, mail_subject):
    user = User.objects.get(username=to_email)
    useremail, created = UserEmailProfile.objects.get_or_create(user=user)
    if useremail.notsendmail:
        if useremail.notsendmail < datetime.now():
            useremail.notsendmail = None
            useremail.save()
            response = conn.send_email(from_email, message, subject, [to_email])
            response_id = response['SendEmailResponse']['SendEmailResult']\
                ['MessageId']
            SentMail.objects.create(receiver=user, subject=mail_subject,
                                    message_key=response_id)
            return HttpResponse("ok")
        else:
            return None
    else:
        response = conn.send_email(from_email, message, subject, [to_email])
        response_id = response['SendEmailResponse']['SendEmailResult']\
            ['MessageId']
        SentMail.objects.create(receiver=user, subject=mail_subject,
                                message_key=response_id)
        return HttpResponse("ok")


import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='hazinses',
    version='0.1',
    packages=['hazinses'],
    include_package_data=True,
    license='BSD License',
    description='A simple Django app for connecting AMAZON SES-CELERY AND BOTO.',
    long_description=README,
    author='Tuna VARGI',
    author_email='tunavargi@gmail.com',
    install_requires=['django', 'boto', 'django-celery'],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License', # example license
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # replace these appropriately if you are using Python 3
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



from django.db import models
try:
    from django.contrib.auth import get_user_model
    User = get_user_model()
except ImportError:
    from django.contrib.auth.models import User


class SNSMessage(models.Model):
    subject = models.TextField()
    message = models.TextField()

    def __unicode__(self):
        return self.subject


class SentMail(models.Model):
    receiver = models.ForeignKey(User)
    subject = models.CharField(max_length=255, blank=True, null=True)
    time = models.DateTimeField(auto_now_add=True)
    message_key = models.CharField(max_length=255, blank=True, null=True)

    def __unicode__(self):
        return (self.receiver.username + "-" + self.subject)


class UserEmailProfile(models.Model):
    user = models.ForeignKey(User)
    notsendmail = models.DateTimeField(blank=True, null=True)




import datetime
import simplejson
from django.http import HttpResponse
from django.utils.decorators import method_decorator
from django.views import generic
from django.views.decorators.csrf import csrf_exempt
from django.conf import settings
from hazinses.models import SNSMessage, UserEmailProfile


class SNSMessageView(generic.View):

    @method_decorator(csrf_exempt)
    def dispatch(self, *args, **kwargs):
        return super(SNSMessageView, self).dispatch(*args, **kwargs)

    def post(self, request, *args, **kwargs):
        json = request.raw_post_data
        js = simplejson.loads(json)
        message = simplejson.loads(js["Message"])
        SNSMessage.objects.create(subject="title", message=request.POST)
        mail = message['mail']['destination'][0]
        useremail = UserEmailProfile.objects.get(user__email=mail)
        if message['notificationType'] == "Bounce":
            useremail.not_send_mail = datetime.now() + datetime.timedelta(
                days=settings.BOUNCE_TIMEDELTA)
        elif message['notificationType'] == "Complaint":
            useremail.not_send_mail = datetime.now() + datetime.timedelta(
                days=settings.COMPLAINT_TIMEDELTA)
        useremail.save()
        return HttpResponse('ok')